polynomials

Struct Monomial

pub struct Monomial {
    pub exponent: u32,
    pub coefficients: f32,
}
Represents a single term in a polynomial, consisting of an exponent and a coefficient.

Fields

exponent: u32

The exponent of the monomial.

coefficients: f32

The coefficient of the monomial.

Implementations

Source

impl Monomial

pub fn new(exponent: u32, coefficients: f32) -> Monomial

Creates a new Monomial with the given exponent and coefficient.

Arguments
  • exponent - The exponent of the monomial.
  • coefficients - The coefficient of the monomial.
Returns

A new Monomial instance.

pub fn default() -> Monomial

Creates a default Monomial with an exponent of 0 and a coefficient of 0.0.

Returns

A default Monomial instance.