UnivariatePolynomial

Struct UnivariatePolynomial 

pub struct UnivariatePolynomial<F: PrimeField> {
    pub degree: Option<u32>,
    /* private fields */
}
Represents a polynomial, which is a sum of monomials.

Fields

degree: Option<u32>

The degree of the polynomial, if known.

Implementations

Source

impl<F: PrimeField> UnivariatePolynomial<F>

pub fn new(monomials: Vec<Monomial<F>>) -> UnivariatePolynomial<F>

Adds a monomial to the polynomial. If a monomial with the same exponent already exists, their coefficients are combined.

Arguments
  • exponent - The exponent of the monomial to add.
  • coefficients - The coefficient of the monomial to add.
pub fn default() -> UnivariatePolynomial<F>

Creates a default Polynomial with no monomials and no degree.

Returns

A default Polynomial instance.

pub fn evaluate(&self, x: F) -> F

Evaluates the polynomial at a given value of x.

Arguments
  • x - The value at which to evaluate the polynomial.
Returns

The result of evaluating the polynomial at x.

pub fn degree(&mut self) -> Option<u32>

Returns the degree of the polynomial.

Returns

The degree of the polynomial, if known.

pub fn interpolate(x: Vec<F>, y: Vec<F>) -> UnivariatePolynomial<F>

Performs Lagrange interpolation to find a polynomial that passes through the given points.

Arguments
  • x - A vector of x-coordinates of the points.
  • y - A vector of y-coordinates of the points.
Returns

A UnivariatePolynomial that passes through the given points.