pub struct UnivariatePolynomial {
pub degree: Option<u32>,
/* private fields */
}Expand description
Represents a polynomial, which is a sum of monomials.
Fields
degree: Option<u32>The degree of the polynomial, if known.
Implementations
Sourceimpl UnivariatePolynomial
impl UnivariatePolynomial
Sourcepub fn new(monomials: Vec<Monomial>) -> UnivariatePolynomial
pub fn new(monomials: Vec<Monomial>) -> UnivariatePolynomial
Adds a monomial to the polynomial. If a monomial with the same exponent already exists, their coefficients are combined.
Arguments
exponent- The exponent of the monomial to add.coefficients- The coefficient of the monomial to add.
Sourcepub fn default() -> UnivariatePolynomial
pub fn default() -> UnivariatePolynomial
Creates a default Polynomial with no monomials and no degree.
Returns
A default Polynomial instance.
Sourcepub fn interpolate(x: Vec<f32>, y: Vec<f32>) -> UnivariatePolynomial
pub fn interpolate(x: Vec<f32>, y: Vec<f32>) -> UnivariatePolynomial